@@ -360,6 +360,8 @@ systray_plugin_screen_changed_idle (gpointer user_data)
   GdkScreen     *screen;
   GError        *error = NULL;
 
+  GDK_THREADS_ENTER ();
+
   /* create a new manager and register this screen */
   plugin->manager = systray_manager_new ();
   g_signal_connect (G_OBJECT (plugin->manager), "icon-added",
@@ -383,6 +385,8 @@ systray_plugin_screen_changed_idle (gpointer user_data)
       g_error_free (error);
     }
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
@@ -585,7 +589,7 @@ systray_plugin_box_expose_event_icon (GtkWidget *child,
       alloc = &child->allocation;
 
       /* skip hidden (see offscreen in box widget) icons */
-      if (alloc->x > 0 && alloc->y > 0)
+      if (alloc->x > -1 && alloc->y > -1)
         {
           gdk_cairo_set_source_pixmap (cr, gtk_widget_get_window (child),
                                        alloc->x, alloc->y);
